%%
%% vereinsbriefcvjmrlinternal.cls
%% Copyright 2024 Lukas Schreiner <lukas.schreiner@cvjm-rhein-lahn.de>
%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%   https://www.latex-project.org/lppl.txt
% and version 1.3c or later is part of all distributions of LaTeX
% version 2008 or later.
%
% This work has the LPPL maintenance status `maintained'.
% 
% The Current Maintainer of this work is Lukas Schreiner.
%
% This work consists of the files vereinsbriefcvjmrlinternal.cls, 
% vereinsbriefcvjmrlinternal.ins and the derived file vereinsbriefcvjmrlinternal.sty.

\def\filedate{2024/07/06}
\def\fileversion{1.1.0}
\def\filename{vereinsbriefcvjmrlinternal.cls}
\NeedsTeXFormat{LaTeX2e}[2001/06/01]

\ProvidesClass{vereinsbriefcvjmrlinternal}[\filedate\space v\fileversion\space vereinsbrief class]

\IfFileExists{ifthen.sty}
  {\RequirePackage{ifthen}}
  {\ClassError{vereinsbriefcvjmrlinternal}
    {LaTeX2e not complete installed or out of date !!!}
    {Get current LaTeX2e !!!}}

\newdimen\VorschubH
\newdimen\VorschubV
\VorschubH = 0.0mm
\VorschubV = 0.0mm
\newcounter{blockzahl}

\def\sprache{ngerman}
\def\telshorttext{Tel.\/:}
\def\telefontext{Telefon\/:}
\def\mobiletext{Mob.\/:}
\def\telefaxtext{Fax\/:}
\def\mailshorttext{E-Mail\/:}
\def\funcshorttext{Funktion\/:}
\def\internetaddr{Internet\/:}
\def\datumtextBig{Datum}
\def\addressText{Anschrift}
\def\banktext{Bankverbindung}
\def\pagetext{Seite}
\def\ihrzeichentext{\footnotesize\textsc{Ihr Zeichen}}
\def\ihrschreibentext{\footnotesize\textsc{Ihr Schreiben vom}}
\def\meinzeichentext{\footnotesize\textsc{Mein Zeichen}}
\def\unserzeichentext{\footnotesize\textsc{Unser Zeichen}}
\def\datumtext{\footnotesize\textsc{Datum}}
\def\datum{\number\day.~\ifcase\month\or Januar\or Februar\or
  M\"arz\or April\or Mai\or Juni\or Juli\or August\or September\or
  Oktober\or November\or Dezember\fi \space\number\year}

\DeclareOption{10pt}{\def\@schrift{0}}
\DeclareOption{11pt}{\def\@schrift{1}}
\DeclareOption{12pt}{\def\@schrift{2}}

\let\@docencoding\@empty
\DeclareOption{ansinew}{\def\@docencoding{ansinew}}
\DeclareOption{applemac}{\def\@docencoding{applemac}}
\DeclareOption{ascii}{\def\@docencoding{ascii}}
\DeclareOption{cp1250}{\def\@docencoding{cp1250}}
\DeclareOption{cp1252}{\def\@docencoding{cp1252}}
\DeclareOption{cp437de}{\def\@docencoding{cp437de}}
\DeclareOption{cp437}{\def\@docencoding{cp437}}
\DeclareOption{cp850}{\def\@docencoding{cp850}}
\DeclareOption{cp852}{\def\@docencoding{cp852}}
\DeclareOption{cp865}{\def\@docencoding{cp865}}
\DeclareOption{decmulti}{\def\@docencoding{decmulti}}
\DeclareOption{latin1}{\def\@docencoding{latin1}}
\DeclareOption{latin2}{\def\@docencoding{latin2}}
\DeclareOption{latin3}{\def\@docencoding{latin3}}
\DeclareOption{latin4}{\def\@docencoding{latin4}}
\DeclareOption{latin5}{\def\@docencoding{latin5}}
\DeclareOption{latin9}{\def\@docencoding{latin9}}
\DeclareOption{utf8}{\def\@docencoding{utf8}}
\DeclareOption{next}{\def\@docencoding{next}}

\DeclareOption{german}{
  \def\sprache{german}
  \def\telshorttext{Tel.\/:}
  \def\funcshorttext{Funktion\/:}
  \def\ihrzeichentext{\footnotesize\textsc{Ihr Zeichen}}
  \def\ihrschreibentext{\footnotesize\textsc{Ihr Schreiben vom}}
  \def\meinzeichentext{\footnotesize\textsc{Mein Zeichen}}
  \def\unserzeichentext{\footnotesize\textsc{Unser Zeichen}}
  \def\datumtext{\footnotesize\textsc{Datum}}
  \def\datum{\number\day.~\ifcase\month\or Januar\or Februar\or
    M\"arz\or April\or Mai\or Juni\or Juli\or August\or September\or
    Oktober\or November\or Dezember\fi \space\number\year}}

\DeclareOption{ngerman}{
  \def\sprache{ngerman}
  \def\telshorttext{Tel.\/:}
  \def\funcshorttext{Funktion\/:}
  \def\ihrzeichentext{\footnotesize\textsc{Ihr Zeichen}}
  \def\ihrschreibentext{\footnotesize\textsc{Ihr Schreiben vom}}
  \def\meinzeichentext{\footnotesize\textsc{Mein Zeichen}}
  \def\unserzeichentext{\footnotesize\textsc{Unser Zeichen}}
  \def\datumtext{\footnotesize\textsc{Datum}}
  \def\datum{\number\day.~\ifcase\month\or Januar\or Februar\or
    M\"arz\or April\or Mai\or Juni\or Juli\or August\or September\or
    Oktober\or November\or Dezember\fi \space\number\year}}

\DeclareOption{english}{
  \def\sprache{english}
  \def\telefontext{Phone\/:}
  \def\ihrzeichentext{\footnotesize\textsc{Your Ref.}}
  \def\ihrschreibentext{\footnotesize\textsc{Your Mail}}
  \def\meinzeichentext{\footnotesize\textsc{My Ref.}}
  \def\unserzeichentext{\footnotesize\textsc{Our Ref.}}
  \def\datumtext{\footnotesize\textsc{Date}}}

\DeclareOption{american}{
  \def\sprache{american}
  \def\telefontext{Phone\/:}
  \def\ihrzeichentext{\footnotesize\textsc{Your Ref.}}
  \def\ihrschreibentext{\footnotesize\textsc{Your Mail}}
  \def\meinzeichentext{\footnotesize\textsc{My Ref.}}
  \def\unserzeichentext{\footnotesize\textsc{Our Ref.}}
  \def\datumtext{\footnotesize\textsc{Date}}}

\message{Language selected: \sprache}

\ExecuteOptions{11pt,@sprache} \ProcessOptions
\LoadClass[1\@schrift pt, a4paper, oneside, final]{letter}[1999/04/29]
\normalsize

\setlength\oddsidemargin{0\p@}
\setlength\evensidemargin{\oddsidemargin}
\setlength\marginparwidth{90\p@}
\setlength\marginparsep{11\p@}
\setlength\marginparpush{5\p@}
\setlength\topmargin{-12.69mm}
\setlength\headheight{4.23mm}
\setlength\headsep{6.35mm}
%\setlength\topskip{3.38mm}
\setlength\topskip{12mm}
\addtolength\footskip{15mm}
\setlength\textheight{210mm}
%\setlength\textwidth{165mm}
\setlength\textwidth{125mm}

\setlength\lineskip{1\p@}
\setlength\normallineskip{1\p@}

\renewcommand\baselinestretch{1}

\advance\topmargin by \VorschubV
\advance\oddsidemargin by \VorschubH
\setlength\evensidemargin{\oddsidemargin}

\AtEndOfClass{\pagestyle{regularpage}}

\def\Name#1{\def\name{#1}} \def\name{}
\def\Logo#1{\def\logo{#1}} \def\logo{}
\def\LogoText#1{\def\logotext{#1}} \def\logotext{}
\def\Schriftzug#1{\def\schriftzug{#1}} \def\schriftzug{}
\def\Website#1{\def\website{#1}} \def\website{}

\def\RetourAdresse#1{\def\retouradresse{#1}} \def\retouradresse{}
\def\Postvermerk#1{\def\postvermerk{#1}} \def\postvermerk{}
\def\PostFrank#1{\def\postfrank{#1}} \def\postfrank{}
\def\Adresse#1{\def\adresse{#1}} \def\adresse{}

\def\EditorName#1{\def\editorname{#1}} \def\editorname{}
\def\EditorAddress#1{\def\editoraddress{#1}} \def\editoraddress{}
\def\EditorPlzOrt#1{\def\editorplzort{#1}} \def\editorplzort{}
\def\EditorTel#1{\def\editortel{#1}} \def\editortel{}
\def\EditorMobile#1{\def\editormobile{#1}} \def\editormobile{}
\def\EditorFax#1{\def\editorfax{#1}} \def\editorfax{}
\def\EditorMail#1{\def\editormail{#1}} \def\editormail{}
\def\EditorFunction#1{\def\editorfunction{#1}} \def\editorfunction{}

\def\ClubName#1{\def\clubname{#1}} \def\clubname{}
\def\ClubAddress#1{\def\clubaddress{#1}} \def\clubaddress{}
\def\ClubPlzOrt#1{\def\clubplzort{#1}} \def\clubplzort{}
\def\ClubMail#1{\def\clubmail{#1}} \def\clubmail{}
\def\ClubWeb#1{\def\clubweb{#1}} \def\clubweb{}
\def\ClubsRegion#1{\def\clubsregion{#1}} \def\clubsregion{}
\def\Clubs#1{\def\clubs{#1}} \def\clubs{}
\def\BankDetails#1{\def\bankdetails{#1}} \def\bankdetails{}

\def\IhrZeichen#1{\def\ihrzeichen{#1}} \def\ihrzeichen{}
\def\IhrSchreiben#1{\def\ihrschreiben{#1}} \def\ihrschreiben{}
\def\MeinZeichen#1{\def\meinzeichen{#1}} \def\meinzeichen{}
\def\Datum#1{\def\datum{#1}} \def\datum{\today}
\def\Ort#1{\def\ort{#1}} \def\ort{}

\def\Betreff#1{\def\betreff{#1}} \def\betreff{}

\def\Anrede#1{\def\anrede{#1}} \def\anrede{}
\def\Gruss#1#2{\def\gruss{#1} \def\grussskip{#2}}
    \def\gruss{} \def\grussskip{}
\def\Unterschrift#1{\def\unterschrift{#1}} \def\unterschrift{}
\def\UnterschriftGrafik#1{\def\unterschriftgrafik{#1}} \def\unterschriftgrafik{}
\def\Funktion#1{\def\funktion{#1}} \def\funktion{}

\def\Anlagen#1{\def\anlagen{#1}} \def\anlagen{}
\def\Verteiler#1{\def\verteiler{#1}} \def\verteiler{}

\long\def\Einrueckung#1{\par\begin{tabular}{@{\hspace{1in}}p{5in}@{}}
    #1\end{tabular}\par}

\def\InInclude#1{\def\ininclude{#1}} \def\ininclude{}

\newif\iftrennlinien\trennlinienfalse
\def\trennlinien{\trennlinientrue}

\newif\iflochermarke\lochermarkefalse
\def\lochermarke{\lochermarketrue}

\newif\iffaltmarken\faltmarkenfalse
\def\faltmarken{\faltmarkentrue}

\newif\ifpagenumber\pagenumberfalse
\def\pagenumber{\pagenumbertrue}

\newif\iffenstermarken\fenstermarkenfalse
\def\fenstermarken{\fenstermarkentrue}

\newif\ifunserzeichen\unserzeichenfalse
\def\unserzeichen{\unserzeichentrue}

\newif\ifprintrefbox

\def\pagerefKey{pagesLTS.arabic}
\newcommand{\setpageref}[1]{\def\pagerefKey{#1}}
\newcommand{\switchpageref}[1]{\newpage\pagenumbering{#1}\setpageref{pagesLTS.#1}}

\newenvironment{vereinsbriefbody}{
  \thispagestyle{firstpage}
  \setlength\unitlength{1mm}

  \c@page\@ne
  \interlinepenalty=200
  \clearpage

  \ifx \ihrzeichen\empty 
    \ifx \ihrschreiben\empty
      \ifx \meinzeichen\empty
        % nothing
      \else 
        \printrefboxtrue
        \makebox[40.5mm][l]{\ihrzeichentext}
        \makebox[35.0mm][l]{\ihrschreibentext} 
        \ifunserzeichen
          \makebox[15.0mm][l]{\unserzeichentext} 
        \else
          \makebox[15.0mm][l]{\meinzeichentext}
        \fi
      \fi
    \else
      \printrefboxtrue
      \makebox[40.5mm][l]{\ihrzeichentext}
      \makebox[35.0mm][l]{\ihrschreibentext} 
      \ifunserzeichen
        \makebox[15.0mm][l]{\unserzeichentext} 
      \else
        \makebox[15.0mm][l]{\meinzeichentext} 
      \fi 
    \fi 
  \else
    \printrefboxtrue
    \makebox[40.5mm][l]{\ihrzeichentext}
    \makebox[35.0mm][l]{\ihrschreibentext} 
    \ifunserzeichen
      \makebox[15.0mm][l]{\unserzeichentext} 
    \else
      \makebox[15.0mm][l]{\meinzeichentext}
    \fi
  \fi
  %\makebox[71.0mm][r]{\datumtext} \\
  \ifprintrefbox
    \ \\
    \makebox[40.5mm][l]{\ihrzeichen}
    \makebox[35.0mm][l]{\ihrschreiben}
    \makebox[15.0mm][l]{\meinzeichen}
    %\makebox[71.0mm][r]{\ort, \datum} \par
    \vspace{5mm}
  \else
    \vspace{11mm}
  \fi

  \ifcase\@ptsize\vspace{0.045pt}\or \vspace{-1.555pt}\or
  \vspace{-2.955pt} \fi

  \ifx \betreff\empty \else \textbf{\betreff} \mbox{} \par \vspace{-1\parskip}
    \vspace{5mm} \fi

  \ifcase\@ptsize\vspace{0.045pt}\or \vspace{-1.555pt}\or
  \vspace{-2.955pt} \fi

  \ifx \anrede\empty \else \anrede \par \fi\nobreak
  \addtolength\textheight{63mm}
  }
  { \renewcommand{\baselinestretch}{1.0}
  \ifcase \@ptsize\relax \normalsize \or \small \or \footnotesize \fi

  \vspace{\grussskip} \par \nobreak \stopbreaks \noindent
  
  \parbox[t]{3.5in}{\raggedright \ignorespaces {\normalsize \ifx
      \gruss\empty \else \gruss \mbox{} 
      \ifthenelse{\equal{\unterschriftgrafik}{\empty}}{\\[16.92mm]}
      {\\ \includegraphics[]{\unterschriftgrafik} \\} \fi \ifx
      \unterschrift\empty \relax \else \unterschrift
    \fi \ifthenelse{\equal{\funktion}{\empty}}{}{\\\funktion\\}} \strut} \ifx \anlagen\empty \else \vspace{1mm} \par {\footnotesize \underline{Anlagen:} \\ \anlagen}
  \par \fi}

\def\ps@firstpage{
  \renewcommand{\baselinestretch}{1}
  \ifcase \@ptsize\relax
    \normalsize \or \small \or \footnotesize
  \fi
  \headheight35pt\headsep55mm
  \def\@oddhead{
    \unitlength1mm
    \begin{picture}(0,0)
      \put(115, -3){
        \parbox{50mm} {
          \includegraphics[scale=0.95]{\logo}
        }
      }
      \put(-28, -13) {
        \parbox{220mm} {
          \textcolor{headrule}{\rule{220mm}{0.5pt}}
        }
      }

      \put(132, -24) {
        \parbox{50mm} {
          \begin{flushleft}
            \textcolor{hks23}{\textbf{\name}}
          \end{flushleft}
        }
      }

      \put(132, -48) {
        \parbox{50mm} {
          \begin{flushleft}
            \editorfunction\\
            \editorname\\
            \editoraddress\\
            \editorplzort\\
            \telshorttext\ \editortel\\
            \telefaxtext\ \editorfax\\
            \editormail
          \end{flushleft}
        }
      }

      \put(132, -75) {
        \parbox{50mm} {
          \begin{flushleft}
            \datum
          \end{flushleft}
        }
      }

      \put(132, -120) {
        \parbox{50mm} {
          \begin{flushleft}
            \textcolor{hks23}{\textbf{\addressText}}\\
            \ \\
            \clubname\\
            \clubaddress\\
            \clubplzort\\
            \clubmail\\
            \clubweb
          \end{flushleft}
        }
      }

      \put(132, -175) {
        \parbox{50mm} {
          \begin{flushleft}
            \textcolor{hks23}{\textbf{\clubsregion}}\\
            \ \\
            \clubs
          \end{flushleft}
        }
      }

      \put(132, -230) {
        \parbox{50mm} {
          \begin{flushleft}
            \textcolor{hks23}{\textbf{\banktext}}\\
            \ \\
            \bankdetails
          \end{flushleft}
        }
      }

      \iftrennlinien \put(0,-15){\textcolor{rulecolor}{\rule{165mm}{0.5pt}}} \fi
      \iflochermarke \put(-20,- 130.50){\line(1,0){4}} \fi
      \iffaltmarken \put(-15,- 75.16){\line(1,0){3}}
        \put(-15,-182.16){\line(1,0){3}} \fi
      \ifx \postfrank\empty
      \par
      \else
        \put(-6,-62){
          \includegraphics[height=121.7pt]{\postfrank}
        }
      \fi
      \put( -9, -22.00){\makebox(85,4)
      {\scriptsize \textrm{\retouradresse}}}
      \put( -9, -22.10){\line(1,0){85}}
      \put(-6,-38){
        \parbox[t]{3in}{
            \ifx \postvermerk\empty \hfill \par
            \else \textbf{\postvermerk} \par \vspace{2mm} 
            \fi \adresse
          }
        }  
      \iffenstermarken
        \put(-9,-18.15){\line( 1, 0){1}} \put(-9,-18.15){\line( 0,-1){1}}
        \put(76,-18.15){\line(-1, 0){1}} \put(76,-18.15){\line( 0,-1){1}}
        \put(-9,-61.00){\line( 1, 0){1}} \put(-9,-61.00){\line( 0, 1){1}}
        \put(76,-61.00){\line(-1, 0){1}} \put(76,-61.00){\line( 0, 1){1}}
        \fi
    \end{picture}
    \hfill
  }
	\def\@oddfoot{
		\unitlength1mm
		\begin{picture}(0,0)
			\put(-1, 25){
				\parbox{149mm}{
					\ifpagenumber \hfill\pagetext\ \thepage\ / \lastpageref{\pagerefKey} \\ \fi
					\tiny \def\@blockbreite{149mm}
					\iftrennlinien \textcolor{rulecolor}{\rule{180mm}{1pt}} \fi
					\footnotesize \def\@blockbreite{147mm}
				}
			}
      
      \put(-3, 45){
          \parbox{130mm}{
            \ifthenelse{\equal{\verteiler}{\empty}}
            {}
            {
              \footnotesize \def\@blockbreite{130mm}
              \begin{minipage}[t]{130mm}
                \underline{Verteiler:} \\
                \verteiler \hspace*{0mm}
              \end{minipage}
            }
          }
        }
		\end{picture} \hfill
	}
  \def\@evenhead{\@oddhead} \def\@evenfoot{\@oddfoot}
}

\def\ps@regularpage{ 
  \renewcommand{\baselinestretch}{1}
  \ifcase \@ptsize\relax
    \normalsize \or \small \or \footnotesize
  \fi
  \headheight35pt\headsep23mm
  \def\@oddhead{  
   \unitlength1mm
    \begin{picture}(0,0)
      \put(115, -3){
        \parbox{50mm} {
          \includegraphics[scale=0.95]{\logo}
        }
      }
      \put(-28, -13) {
        \parbox{220mm} {
          \textcolor{headrule}{\rule{220mm}{0.5pt}}
        }
      }
      \iftrennlinien \put(0,-15){\textcolor{rulecolor}{\rule{165mm}{0.5pt}}} \fi
    \end{picture}
    \hfill
  }
  \def\@oddfoot{
    \unitlength1mm
    \begin{picture}(0,0)
      \put(-63, \if\ininclude1 -6 \else -7 \fi){
        \parbox{149mm}{
	       \ifpagenumber \hfill\pagetext\ \thepage\ / \pageref{\pagerefKey} \\ \fi
         \tiny \def\@blockbreite{170mm}
         \iftrennlinien \textcolor{rulecolor}{\rule{180mm}{1pt}} \fi
        }
      }
    \end{picture}
  } 
  \def\@evenfoot{\@oddfoot}
}
\message{Before loading babel - language: \sprache}
\IfFileExists{babel.sty}
  {\RequirePackage[\sprache]{babel}[2001/03/01]}
  {\ClassError{vereinsbriefbody}
    {Babel not installed !!!}
    {Get babel package !!!}}

\ifx \@docencoding\empty \else
\IfFileExists{inputenc.sty}
  {\RequirePackage[\@docencoding]{inputenc}}
  {\ClassError{vereinsbriefbody}
    {LaTeX2e not complete installed or out of date !!!}
    {Get current LaTeX2e !!!}}
\fi

\IfFileExists{marvosym.sty}
  {\RequirePackage{marvosym}}
  {}{}
\IfFileExists{europs.sty}
  {\RequirePackage{europs}}
  {}{}
\IfFileExists{eurosym.sty}
  {\RequirePackage{eurosym}}
  {}{}

\IfFileExists{graphicx.sty}
  {\RequirePackage{graphicx}}
  {}{}

\IfFileExists{pageslts.sty}
  {\RequirePackage[pagecontinue=false,alphMult=ab,AlphMulti=AB,fnsymbolmult=true,romanMult=true,RomanMulti=true]{pageslts}}
  {\ClassError{vereinsbriefbody}
  {pageslts not complete installed !!!}}


\endinput
%%
%% End of file `vereinsbriefcvjmrlinternal.cls'.
